@@ -1,23 +1,23 @@
 from facebook_users.factories import UserFactory
-from facebook_pages.factories import PageFactory
+#from facebook_pages.factories import PageFactory
 from models import Post, Comment, PostOwner
 from datetime import datetime
 import factory
 import random
 
-class PostOwnerFactory(factory.Factory):
+class PostOwnerFactory(factory.DjangoModelFactory):
     FACTORY_FOR = PostOwner
 
-class PostFactory(factory.Factory):
+class PostFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Post
 
     created_time = datetime.now()
 
 #    owners = factory.SubFactory(UserFactory)
     author = factory.SubFactory(UserFactory)
-    graph_id = factory.Sequence(lambda n: n)
+    graph_id = factory.LazyAttributeSequence(lambda o, n: '%s_%s' % (n, n))
 
-class CommentFactory(factory.Factory):
+class CommentFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Comment
 
     created_time = datetime.now()
